@@ -9,10 +9,11 @@
 # messages printed. Takes an optional logfile as first command
 # line parameter
 
-
+from __future__ import annotations
 
 import os
 import sys
+import typing
 
 if hasattr(sys, "frozen"):
     if sys.frozen == 'windows_exe':
@@ -116,9 +117,8 @@ from mercurial.windows import posixfile, unlink, rename
 from tortoisehg.util.i18n import _
 from tortoisehg.util import hglib, thread2, paths, shlib, version
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
-        Any,
         Iterable,
         List,
         Set,
@@ -135,8 +135,7 @@ class Logger:
     def __init__(self):
         self.file = None
 
-    def setfile(self, name):
-        # type: (Text) -> None
+    def setfile(self, name: str) -> None:
         oname = name + '.old'
         try:
             rename(hglib.fromunicode(name), hglib.fromunicode(oname))
@@ -146,8 +145,7 @@ class Logger:
         self.msg('%s, Version %s' % (APP_TITLE, version.version()))
         self.msg('Logging to file started')
 
-    def msg(self, msg):
-        # type: (Text) -> None
+    def msg(self, msg: str) -> None:
         ts = '[%s] ' % time.strftime('%c')
         f = self.file
         if f:
@@ -162,8 +160,7 @@ logger = Logger()
 
 iconcache = {}
 
-def load_icon(name):
-    # type: (Text) -> Any
+def load_icon(name: str):
     from tortoisehg.util.paths import get_tortoise_icon
     iconPathName = get_tortoise_icon(name)
     if iconPathName and os.path.isfile(iconPathName):
@@ -174,16 +171,14 @@ def load_icon(name):
         hicon = LoadIcon(0, win32con.IDI_APPLICATION)
     return hicon
 
-def get_icon(name):
-    # type: (Text) -> Any
+def get_icon(name: str):
     try:
         return iconcache[name]
     except KeyError:
         iconcache[name] = load_icon(name)
         return iconcache[name]
 
-def SetIcon(hwnd, name, add=False):
-    # type: (Any, Text, bool) -> None
+def SetIcon(hwnd, name: str, add: bool = False) -> None:
     # Try and find a custom icon
     if '--noicon' in sys.argv:
         return
@@ -328,8 +323,7 @@ PIPENAME += GetUserName()
 
 PIPEBUFSIZE = 4096
 
-def getrepos(batch):
-    # type: (Iterable[Text]) -> Tuple[Set[Text], Set[Text]]
+def getrepos(batch: Iterable[str]) -> Tuple[Set[str], Set[str]]:
     roots = set()
     notifypaths = set()
     for path in batch:
@@ -350,8 +344,7 @@ def getrepos(batch):
             notifypaths.add(path)
     return roots, notifypaths
 
-def update_batch(batch):
-    # type: (Iterable[Text]) -> None
+def update_batch(batch: Iterable[str]) -> None:
     '''updates thgstatus for all paths in batch'''
     roots, notifypaths = getrepos(batch)
     if roots:
@@ -376,7 +369,7 @@ def update_batch(batch):
                         updated_any = True
                     shlib.shell_notify([hglib.fromunicode(r)], noassoc=True)
                     logger.msg('Updated ' + r)
-                except (IOError, OSError):
+                except OSError:
                     print("IOError or OSError on updating %s (check permissions)" % r)
                     logger.msg('Failed updating %s (check permissions)' % r)
                     failedroots.add(r)
@@ -432,9 +425,9 @@ def get_config():
                     plist = [i.strip() for i in promoted.split(',')]
 
                     with CreateKey(HKEY_CURRENT_USER, r'Software\TortoiseHg') as hkey2:
-                        if u'log' in plist:
-                            idx = plist.index(u'log')
-                            plist[idx] = u'workbench'
+                        if 'log' in plist:
+                            idx = plist.index('log')
+                            plist[idx] = 'workbench'
                             SetValueEx(hkey2, 'PromotedItems', 0, REG_SZ, ','.join(plist))
                         SetValueEx(hkey2, 'ContextMenuVersion', 0, REG_SZ, '2')
             except OSError:
@@ -443,8 +436,7 @@ def get_config():
         pass
     return show_taskbaricon, hgighlight_taskbaricon
 
-def update(args, hwnd):
-    # type: (List[Text], Any) -> None
+def update(args: List[str], hwnd) -> None:
     batch = []
     r = args[0]
     print("got update request %s (first in batch)" % r)
@@ -475,8 +467,7 @@ def update(args, hwnd):
     if show and highlight:
         SetIcon(hwnd, "hg.ico")
 
-def remove(args):
-    # type: (List[Text]) -> None
+def remove(args: List[str]) -> None:
     path = args[0]
     logger.msg('Removing ' + path)
     roots, notifypaths = getrepos([path])
@@ -490,14 +481,13 @@ def remove(args):
                 f.close()
                 if not e.startswith(b'@@noicons'):
                     unlink(fn)
-            except (IOError, OSError) as e:
+            except OSError as e:
                 if e.errno != errno.ENOENT:
                     logger.msg("Error while trying to remove %s (%s)" % (tfn, e))
         if notifypaths:
             shlib.shell_notify([hglib.fromunicode(p) for p in notifypaths])
 
-def dispatch(req, cmd, args, hwnd):
-    # type: (Any, Text, List[Text], Any) -> None
+def dispatch(req, cmd: str, args: List[str], hwnd) -> None:
     print("dispatch(%s)" % req)
     if cmd == 'update':
         update(args, hwnd)
@@ -646,7 +636,7 @@ def main():
         logfilename = os.path.join(appdir, 'TortoiseHg', 'OverlayServerLog.txt')
         try:
             os.makedirs(os.path.dirname(logfilename))
-        except EnvironmentError:
+        except OSError:
             pass
         logger.setfile(logfilename)
 
