@@ -1,6 +1,6 @@
 """Helper functions or classes imported from test case"""
 
-
+from __future__ import annotations
 
 import os
 import re
@@ -8,9 +8,14 @@ import sys
 import time
 from collections import defaultdict
 
-from tortoisehg.hgqt.qtcore import (
-    QTextCodec,
-)
+try:
+    from tortoisehg.hgqt.qtcore import (
+        QTextCodec,
+    )
+except ImportError:
+    # QStringConverter is supposed to be the replacement on Qt6, but is missing
+    # a lot of stuff.
+    QTextCodec = None
 
 from mercurial import (
     dispatch,
@@ -50,7 +55,7 @@ def guessmtimedelay(dir):
         os.close(fd)
         os.unlink(path)
 
-class EncodingPatcher(object):
+class EncodingPatcher:
     """Temporarily change locale encoding"""
 
     def __init__(self, encoding, fallbackencoding=None):
@@ -110,7 +115,7 @@ def with_encoding(encoding, fallbackencoding=None):
         return wrapper
     return deco
 
-class HgClient(object):
+class HgClient:
     """Mercurial client to set up fixture repository
 
     >>> hg = HgClient(b'/tmp/foo')
@@ -228,7 +233,7 @@ class InvalidGraphLine(Exception):
     pass
 
 
-class GraphBuilder(object):
+class GraphBuilder:
     _re_graphline = re.compile(r"""^
                 (?P<graph>[ o0-9|/\\+\-]*)       #graph
                 (\s*\[(?P<params>[^#]+)\]\s*)?   #params
@@ -401,7 +406,7 @@ class GraphBuilder(object):
 
             next_revs[i] = parents
 
-        if (set(i for (i, c) in enumerate(prevline) if c in r'|\/')
+        if ({i for (i, c) in enumerate(prevline) if c in r'|\/'}
             - visitededges):
             raise InvalidGraphLine('isolated edge')
 
