@@ -1,4 +1,4 @@
-
+from __future__ import annotations
 
 from unittest import mock
 import os
@@ -677,14 +677,18 @@ class ManifestModelLargeFilesTest(unittest.TestCase):
         self.assertEqual('C', m.fileStatus(m.indexFromPath('baz/large')))
 
 
-_aloha_ja = u'\u3042\u308d\u306f\u30fc'
+_aloha_ja = '\u3042\u308d\u306f\u30fc'
 
 class ManifestModelEucjpTest(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         # TODO: make this compatible with binary-unsafe filesystem
         if os.name != 'posix' or sys.platform == 'darwin':
-            raise SkipTest
+            raise unittest.SkipTest
+        # TODO: figure out the replacement for QTextCodec on Qt6
+        if helpers.QTextCodec is None:
+            raise unittest.SkipTest
+
         cls.encodingpatch = helpers.patchencoding('euc-jp')
 
         # include non-ascii char in repo path to test concatenation
